@@ -16,6 +16,16 @@ module RubyDebianDev
     }
   end
 
+  has_support_for 'ruby2.5' do
+    {
+      version:             '2.5',
+      binary:              '/usr/bin/ruby2.5',
+      api_version:         '2.5.0',
+      shared_library:      'libruby2.5',
+      min_ruby_dependency: 'ruby (>= 1:2.5~0)',
+    }
+  end
+
   def self.min_ruby_dependency_for(shared_library)
     RUBY_INTERPRETERS.each do |int,data|
       if data[:shared_library] == shared_library
